# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: steammessages_partnerapps.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import service as _service
from google.protobuf import service_reflection
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import steam.protobufs.steammessages_base_pb2 as steammessages__base__pb2
import steam.protobufs.steammessages_unified_base_pb2 as steammessages__unified__base__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='steammessages_partnerapps.proto',
  package='',
  syntax='proto2',
  serialized_options=b'\220\001\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1fsteammessages_partnerapps.proto\x1a\x18steammessages_base.proto\x1a steammessages_unified_base.proto\"J\n\'CPartnerApps_RequestUploadToken_Request\x12\x10\n\x08\x66ilename\x18\x01 \x01(\t\x12\r\n\x05\x61ppid\x18\x02 \x01(\r\"f\n(CPartnerApps_RequestUploadToken_Response\x12\x14\n\x0cupload_token\x18\x01 \x01(\x04\x12\x10\n\x08location\x18\x02 \x01(\t\x12\x12\n\nrouting_id\x18\x03 \x01(\x04\"]\n!CPartnerApps_FinishUpload_Request\x12\x14\n\x0cupload_token\x18\x01 \x01(\x04\x12\x12\n\nrouting_id\x18\x02 \x01(\x04\x12\x0e\n\x06\x61pp_id\x18\x03 \x01(\r\"H\n(CPartnerApps_FinishUploadKVSign_Response\x12\x1c\n\x14signed_installscript\x18\x01 \x01(\t\"\x88\x01\n*CPartnerApps_FinishUploadLegacyDRM_Request\x12\x14\n\x0cupload_token\x18\x01 \x01(\x04\x12\x12\n\nrouting_id\x18\x02 \x01(\x04\x12\x0e\n\x06\x61pp_id\x18\x03 \x01(\r\x12\r\n\x05\x66lags\x18\x04 \x01(\r\x12\x11\n\ttool_name\x18\x05 \x01(\t\">\n+CPartnerApps_FinishUploadLegacyDRM_Response\x12\x0f\n\x07\x66ile_id\x18\x01 \x01(\t\"$\n\"CPartnerApps_FinishUpload_Response\"\x89\x01\n&CPartnerApps_FinishUploadDepot_Request\x12\x14\n\x0cupload_token\x18\x01 \x01(\x04\x12\x12\n\nrouting_id\x18\x02 \x01(\x04\x12\x0e\n\x06\x61pp_id\x18\x03 \x01(\r\x12\x10\n\x08\x64\x65pot_id\x18\x04 \x01(\r\x12\x13\n\x0b\x62uild_flags\x18\x05 \x01(\r\")\n\'CPartnerApps_FinishUploadDepot_Response\"T\n(CPartnerApps_GetDepotBuildResult_Request\x12\x14\n\x0cupload_token\x18\x01 \x01(\x04\x12\x12\n\nrouting_id\x18\x02 \x01(\x04\"S\n)CPartnerApps_GetDepotBuildResult_Response\x12\x13\n\x0bmanifest_id\x18\x01 \x01(\x04\x12\x11\n\terror_msg\x18\x02 \x01(\t\"5\n#CPartnerApps_FindDRMUploads_Request\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\x05\"\xb4\x01\n\x1e\x43PartnerApps_ExistingDRMUpload\x12\x0f\n\x07\x66ile_id\x18\x01 \x01(\t\x12\x0e\n\x06\x61pp_id\x18\x02 \x01(\r\x12\x10\n\x08\x61\x63tor_id\x18\x03 \x01(\x05\x12\x15\n\rsupplied_name\x18\x05 \x01(\t\x12\r\n\x05\x66lags\x18\x06 \x01(\r\x12\x10\n\x08mod_type\x18\x07 \x01(\t\x12\x11\n\ttimestamp\x18\x08 \x01(\x07\x12\x14\n\x0corig_file_id\x18\t \x01(\t\"X\n$CPartnerApps_FindDRMUploads_Response\x12\x30\n\x07uploads\x18\x01 \x03(\x0b\x32\x1f.CPartnerApps_ExistingDRMUpload\"@\n\x1d\x43PartnerApps_Download_Request\x12\x0f\n\x07\x66ile_id\x18\x01 \x01(\t\x12\x0e\n\x06\x61pp_id\x18\x02 \x01(\x05\"F\n\x1e\x43PartnerApps_Download_Response\x12\x14\n\x0c\x64ownload_url\x18\x01 \x01(\t\x12\x0e\n\x06\x61pp_id\x18\x02 \x01(\x05\x32\xa1\x0e\n\x0bPartnerApps\x12\xb1\x01\n\x18RequestKVSignUploadToken\x12(.CPartnerApps_RequestUploadToken_Request\x1a).CPartnerApps_RequestUploadToken_Response\"@\x82\xb5\x18<Request upload token for installscript file upload / signing\x12\xae\x01\n\x15RequestDRMUploadToken\x12(.CPartnerApps_RequestUploadToken_Request\x1a).CPartnerApps_RequestUploadToken_Response\"@\x82\xb5\x18<Request upload token for executable file upload / processing\x12\xb5\x01\n\x15RequestCEGUploadToken\x12(.CPartnerApps_RequestUploadToken_Request\x1a).CPartnerApps_RequestUploadToken_Response\"G\x82\xb5\x18\x43Request upload token for custom executable file upload / processing\x12\xa3\x01\n\x17RequestDepotUploadToken\x12(.CPartnerApps_RequestUploadToken_Request\x1a).CPartnerApps_RequestUploadToken_Response\"3\x82\xb5\x18/Request upload token for steampipe depot upload\x12\xab\x01\n\x12\x46inishUploadKVSign\x12\".CPartnerApps_FinishUpload_Request\x1a).CPartnerApps_FinishUploadKVSign_Response\"F\x82\xb5\x18\x42\x43ommit method to sign an installscript after an upload is complete\x12\xa4\x01\n\x15\x46inishUploadDRMUpload\x12+.CPartnerApps_FinishUploadLegacyDRM_Request\x1a,.CPartnerApps_FinishUploadLegacyDRM_Response\"0\x82\xb5\x18,Commit method for executable file processing\x12\x99\x01\n\x15\x46inishUploadCEGUpload\x12\".CPartnerApps_FinishUpload_Request\x1a#.CPartnerApps_FinishUpload_Response\"7\x82\xb5\x18\x33\x43ommit method for custom executable file processing\x12\xa5\x01\n\x17\x46inishUploadDepotUpload\x12\'.CPartnerApps_FinishUploadDepot_Request\x1a(.CPartnerApps_FinishUploadDepot_Response\"7\x82\xb5\x18\x33\x43ommit method for custom executable file processing\x12\xa4\x01\n\x13GetDepotBuildResult\x12).CPartnerApps_GetDepotBuildResult_Request\x1a*.CPartnerApps_GetDepotBuildResult_Response\"6\x82\xb5\x18\x32Get build status for previously uploaded depot ZIP\x12\x8d\x01\n\x0e\x46indDRMUploads\x12$.CPartnerApps_FindDRMUploads_Request\x1a%.CPartnerApps_FindDRMUploads_Response\".\x82\xb5\x18*Finds N most recent prior uploads by appid\x12K\n\x08\x44ownload\x12\x1e.CPartnerApps_Download_Request\x1a\x1f.CPartnerApps_Download_Response\x1a\x32\x82\xb5\x18.Service methods for app management by partnersB\x03\x90\x01\x01'
  ,
  dependencies=[steammessages__base__pb2.DESCRIPTOR,steammessages__unified__base__pb2.DESCRIPTOR,])




_CPARTNERAPPS_REQUESTUPLOADTOKEN_REQUEST = _descriptor.Descriptor(
  name='CPartnerApps_RequestUploadToken_Request',
  full_name='CPartnerApps_RequestUploadToken_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='filename', full_name='CPartnerApps_RequestUploadToken_Request.filename', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='appid', full_name='CPartnerApps_RequestUploadToken_Request.appid', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=95,
  serialized_end=169,
)


_CPARTNERAPPS_REQUESTUPLOADTOKEN_RESPONSE = _descriptor.Descriptor(
  name='CPartnerApps_RequestUploadToken_Response',
  full_name='CPartnerApps_RequestUploadToken_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='upload_token', full_name='CPartnerApps_RequestUploadToken_Response.upload_token', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='location', full_name='CPartnerApps_RequestUploadToken_Response.location', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='routing_id', full_name='CPartnerApps_RequestUploadToken_Response.routing_id', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=171,
  serialized_end=273,
)


_CPARTNERAPPS_FINISHUPLOAD_REQUEST = _descriptor.Descriptor(
  name='CPartnerApps_FinishUpload_Request',
  full_name='CPartnerApps_FinishUpload_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='upload_token', full_name='CPartnerApps_FinishUpload_Request.upload_token', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='routing_id', full_name='CPartnerApps_FinishUpload_Request.routing_id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='app_id', full_name='CPartnerApps_FinishUpload_Request.app_id', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=275,
  serialized_end=368,
)


_CPARTNERAPPS_FINISHUPLOADKVSIGN_RESPONSE = _descriptor.Descriptor(
  name='CPartnerApps_FinishUploadKVSign_Response',
  full_name='CPartnerApps_FinishUploadKVSign_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='signed_installscript', full_name='CPartnerApps_FinishUploadKVSign_Response.signed_installscript', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=370,
  serialized_end=442,
)


_CPARTNERAPPS_FINISHUPLOADLEGACYDRM_REQUEST = _descriptor.Descriptor(
  name='CPartnerApps_FinishUploadLegacyDRM_Request',
  full_name='CPartnerApps_FinishUploadLegacyDRM_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='upload_token', full_name='CPartnerApps_FinishUploadLegacyDRM_Request.upload_token', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='routing_id', full_name='CPartnerApps_FinishUploadLegacyDRM_Request.routing_id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='app_id', full_name='CPartnerApps_FinishUploadLegacyDRM_Request.app_id', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='flags', full_name='CPartnerApps_FinishUploadLegacyDRM_Request.flags', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tool_name', full_name='CPartnerApps_FinishUploadLegacyDRM_Request.tool_name', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=445,
  serialized_end=581,
)


_CPARTNERAPPS_FINISHUPLOADLEGACYDRM_RESPONSE = _descriptor.Descriptor(
  name='CPartnerApps_FinishUploadLegacyDRM_Response',
  full_name='CPartnerApps_FinishUploadLegacyDRM_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='file_id', full_name='CPartnerApps_FinishUploadLegacyDRM_Response.file_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=583,
  serialized_end=645,
)


_CPARTNERAPPS_FINISHUPLOAD_RESPONSE = _descriptor.Descriptor(
  name='CPartnerApps_FinishUpload_Response',
  full_name='CPartnerApps_FinishUpload_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=647,
  serialized_end=683,
)


_CPARTNERAPPS_FINISHUPLOADDEPOT_REQUEST = _descriptor.Descriptor(
  name='CPartnerApps_FinishUploadDepot_Request',
  full_name='CPartnerApps_FinishUploadDepot_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='upload_token', full_name='CPartnerApps_FinishUploadDepot_Request.upload_token', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='routing_id', full_name='CPartnerApps_FinishUploadDepot_Request.routing_id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='app_id', full_name='CPartnerApps_FinishUploadDepot_Request.app_id', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='depot_id', full_name='CPartnerApps_FinishUploadDepot_Request.depot_id', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='build_flags', full_name='CPartnerApps_FinishUploadDepot_Request.build_flags', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=686,
  serialized_end=823,
)


_CPARTNERAPPS_FINISHUPLOADDEPOT_RESPONSE = _descriptor.Descriptor(
  name='CPartnerApps_FinishUploadDepot_Response',
  full_name='CPartnerApps_FinishUploadDepot_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=825,
  serialized_end=866,
)


_CPARTNERAPPS_GETDEPOTBUILDRESULT_REQUEST = _descriptor.Descriptor(
  name='CPartnerApps_GetDepotBuildResult_Request',
  full_name='CPartnerApps_GetDepotBuildResult_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='upload_token', full_name='CPartnerApps_GetDepotBuildResult_Request.upload_token', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='routing_id', full_name='CPartnerApps_GetDepotBuildResult_Request.routing_id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=868,
  serialized_end=952,
)


_CPARTNERAPPS_GETDEPOTBUILDRESULT_RESPONSE = _descriptor.Descriptor(
  name='CPartnerApps_GetDepotBuildResult_Response',
  full_name='CPartnerApps_GetDepotBuildResult_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='manifest_id', full_name='CPartnerApps_GetDepotBuildResult_Response.manifest_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='error_msg', full_name='CPartnerApps_GetDepotBuildResult_Response.error_msg', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=954,
  serialized_end=1037,
)


_CPARTNERAPPS_FINDDRMUPLOADS_REQUEST = _descriptor.Descriptor(
  name='CPartnerApps_FindDRMUploads_Request',
  full_name='CPartnerApps_FindDRMUploads_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='app_id', full_name='CPartnerApps_FindDRMUploads_Request.app_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1039,
  serialized_end=1092,
)


_CPARTNERAPPS_EXISTINGDRMUPLOAD = _descriptor.Descriptor(
  name='CPartnerApps_ExistingDRMUpload',
  full_name='CPartnerApps_ExistingDRMUpload',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='file_id', full_name='CPartnerApps_ExistingDRMUpload.file_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='app_id', full_name='CPartnerApps_ExistingDRMUpload.app_id', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='actor_id', full_name='CPartnerApps_ExistingDRMUpload.actor_id', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='supplied_name', full_name='CPartnerApps_ExistingDRMUpload.supplied_name', index=3,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='flags', full_name='CPartnerApps_ExistingDRMUpload.flags', index=4,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mod_type', full_name='CPartnerApps_ExistingDRMUpload.mod_type', index=5,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='CPartnerApps_ExistingDRMUpload.timestamp', index=6,
      number=8, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='orig_file_id', full_name='CPartnerApps_ExistingDRMUpload.orig_file_id', index=7,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1095,
  serialized_end=1275,
)


_CPARTNERAPPS_FINDDRMUPLOADS_RESPONSE = _descriptor.Descriptor(
  name='CPartnerApps_FindDRMUploads_Response',
  full_name='CPartnerApps_FindDRMUploads_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='uploads', full_name='CPartnerApps_FindDRMUploads_Response.uploads', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1277,
  serialized_end=1365,
)


_CPARTNERAPPS_DOWNLOAD_REQUEST = _descriptor.Descriptor(
  name='CPartnerApps_Download_Request',
  full_name='CPartnerApps_Download_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='file_id', full_name='CPartnerApps_Download_Request.file_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='app_id', full_name='CPartnerApps_Download_Request.app_id', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1367,
  serialized_end=1431,
)


_CPARTNERAPPS_DOWNLOAD_RESPONSE = _descriptor.Descriptor(
  name='CPartnerApps_Download_Response',
  full_name='CPartnerApps_Download_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='download_url', full_name='CPartnerApps_Download_Response.download_url', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='app_id', full_name='CPartnerApps_Download_Response.app_id', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1433,
  serialized_end=1503,
)

_CPARTNERAPPS_FINDDRMUPLOADS_RESPONSE.fields_by_name['uploads'].message_type = _CPARTNERAPPS_EXISTINGDRMUPLOAD
DESCRIPTOR.message_types_by_name['CPartnerApps_RequestUploadToken_Request'] = _CPARTNERAPPS_REQUESTUPLOADTOKEN_REQUEST
DESCRIPTOR.message_types_by_name['CPartnerApps_RequestUploadToken_Response'] = _CPARTNERAPPS_REQUESTUPLOADTOKEN_RESPONSE
DESCRIPTOR.message_types_by_name['CPartnerApps_FinishUpload_Request'] = _CPARTNERAPPS_FINISHUPLOAD_REQUEST
DESCRIPTOR.message_types_by_name['CPartnerApps_FinishUploadKVSign_Response'] = _CPARTNERAPPS_FINISHUPLOADKVSIGN_RESPONSE
DESCRIPTOR.message_types_by_name['CPartnerApps_FinishUploadLegacyDRM_Request'] = _CPARTNERAPPS_FINISHUPLOADLEGACYDRM_REQUEST
DESCRIPTOR.message_types_by_name['CPartnerApps_FinishUploadLegacyDRM_Response'] = _CPARTNERAPPS_FINISHUPLOADLEGACYDRM_RESPONSE
DESCRIPTOR.message_types_by_name['CPartnerApps_FinishUpload_Response'] = _CPARTNERAPPS_FINISHUPLOAD_RESPONSE
DESCRIPTOR.message_types_by_name['CPartnerApps_FinishUploadDepot_Request'] = _CPARTNERAPPS_FINISHUPLOADDEPOT_REQUEST
DESCRIPTOR.message_types_by_name['CPartnerApps_FinishUploadDepot_Response'] = _CPARTNERAPPS_FINISHUPLOADDEPOT_RESPONSE
DESCRIPTOR.message_types_by_name['CPartnerApps_GetDepotBuildResult_Request'] = _CPARTNERAPPS_GETDEPOTBUILDRESULT_REQUEST
DESCRIPTOR.message_types_by_name['CPartnerApps_GetDepotBuildResult_Response'] = _CPARTNERAPPS_GETDEPOTBUILDRESULT_RESPONSE
DESCRIPTOR.message_types_by_name['CPartnerApps_FindDRMUploads_Request'] = _CPARTNERAPPS_FINDDRMUPLOADS_REQUEST
DESCRIPTOR.message_types_by_name['CPartnerApps_ExistingDRMUpload'] = _CPARTNERAPPS_EXISTINGDRMUPLOAD
DESCRIPTOR.message_types_by_name['CPartnerApps_FindDRMUploads_Response'] = _CPARTNERAPPS_FINDDRMUPLOADS_RESPONSE
DESCRIPTOR.message_types_by_name['CPartnerApps_Download_Request'] = _CPARTNERAPPS_DOWNLOAD_REQUEST
DESCRIPTOR.message_types_by_name['CPartnerApps_Download_Response'] = _CPARTNERAPPS_DOWNLOAD_RESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CPartnerApps_RequestUploadToken_Request = _reflection.GeneratedProtocolMessageType('CPartnerApps_RequestUploadToken_Request', (_message.Message,), {
  'DESCRIPTOR' : _CPARTNERAPPS_REQUESTUPLOADTOKEN_REQUEST,
  '__module__' : 'steammessages_partnerapps_pb2'
  # @@protoc_insertion_point(class_scope:CPartnerApps_RequestUploadToken_Request)
  })
_sym_db.RegisterMessage(CPartnerApps_RequestUploadToken_Request)

CPartnerApps_RequestUploadToken_Response = _reflection.GeneratedProtocolMessageType('CPartnerApps_RequestUploadToken_Response', (_message.Message,), {
  'DESCRIPTOR' : _CPARTNERAPPS_REQUESTUPLOADTOKEN_RESPONSE,
  '__module__' : 'steammessages_partnerapps_pb2'
  # @@protoc_insertion_point(class_scope:CPartnerApps_RequestUploadToken_Response)
  })
_sym_db.RegisterMessage(CPartnerApps_RequestUploadToken_Response)

CPartnerApps_FinishUpload_Request = _reflection.GeneratedProtocolMessageType('CPartnerApps_FinishUpload_Request', (_message.Message,), {
  'DESCRIPTOR' : _CPARTNERAPPS_FINISHUPLOAD_REQUEST,
  '__module__' : 'steammessages_partnerapps_pb2'
  # @@protoc_insertion_point(class_scope:CPartnerApps_FinishUpload_Request)
  })
_sym_db.RegisterMessage(CPartnerApps_FinishUpload_Request)

CPartnerApps_FinishUploadKVSign_Response = _reflection.GeneratedProtocolMessageType('CPartnerApps_FinishUploadKVSign_Response', (_message.Message,), {
  'DESCRIPTOR' : _CPARTNERAPPS_FINISHUPLOADKVSIGN_RESPONSE,
  '__module__' : 'steammessages_partnerapps_pb2'
  # @@protoc_insertion_point(class_scope:CPartnerApps_FinishUploadKVSign_Response)
  })
_sym_db.RegisterMessage(CPartnerApps_FinishUploadKVSign_Response)

CPartnerApps_FinishUploadLegacyDRM_Request = _reflection.GeneratedProtocolMessageType('CPartnerApps_FinishUploadLegacyDRM_Request', (_message.Message,), {
  'DESCRIPTOR' : _CPARTNERAPPS_FINISHUPLOADLEGACYDRM_REQUEST,
  '__module__' : 'steammessages_partnerapps_pb2'
  # @@protoc_insertion_point(class_scope:CPartnerApps_FinishUploadLegacyDRM_Request)
  })
_sym_db.RegisterMessage(CPartnerApps_FinishUploadLegacyDRM_Request)

CPartnerApps_FinishUploadLegacyDRM_Response = _reflection.GeneratedProtocolMessageType('CPartnerApps_FinishUploadLegacyDRM_Response', (_message.Message,), {
  'DESCRIPTOR' : _CPARTNERAPPS_FINISHUPLOADLEGACYDRM_RESPONSE,
  '__module__' : 'steammessages_partnerapps_pb2'
  # @@protoc_insertion_point(class_scope:CPartnerApps_FinishUploadLegacyDRM_Response)
  })
_sym_db.RegisterMessage(CPartnerApps_FinishUploadLegacyDRM_Response)

CPartnerApps_FinishUpload_Response = _reflection.GeneratedProtocolMessageType('CPartnerApps_FinishUpload_Response', (_message.Message,), {
  'DESCRIPTOR' : _CPARTNERAPPS_FINISHUPLOAD_RESPONSE,
  '__module__' : 'steammessages_partnerapps_pb2'
  # @@protoc_insertion_point(class_scope:CPartnerApps_FinishUpload_Response)
  })
_sym_db.RegisterMessage(CPartnerApps_FinishUpload_Response)

CPartnerApps_FinishUploadDepot_Request = _reflection.GeneratedProtocolMessageType('CPartnerApps_FinishUploadDepot_Request', (_message.Message,), {
  'DESCRIPTOR' : _CPARTNERAPPS_FINISHUPLOADDEPOT_REQUEST,
  '__module__' : 'steammessages_partnerapps_pb2'
  # @@protoc_insertion_point(class_scope:CPartnerApps_FinishUploadDepot_Request)
  })
_sym_db.RegisterMessage(CPartnerApps_FinishUploadDepot_Request)

CPartnerApps_FinishUploadDepot_Response = _reflection.GeneratedProtocolMessageType('CPartnerApps_FinishUploadDepot_Response', (_message.Message,), {
  'DESCRIPTOR' : _CPARTNERAPPS_FINISHUPLOADDEPOT_RESPONSE,
  '__module__' : 'steammessages_partnerapps_pb2'
  # @@protoc_insertion_point(class_scope:CPartnerApps_FinishUploadDepot_Response)
  })
_sym_db.RegisterMessage(CPartnerApps_FinishUploadDepot_Response)

CPartnerApps_GetDepotBuildResult_Request = _reflection.GeneratedProtocolMessageType('CPartnerApps_GetDepotBuildResult_Request', (_message.Message,), {
  'DESCRIPTOR' : _CPARTNERAPPS_GETDEPOTBUILDRESULT_REQUEST,
  '__module__' : 'steammessages_partnerapps_pb2'
  # @@protoc_insertion_point(class_scope:CPartnerApps_GetDepotBuildResult_Request)
  })
_sym_db.RegisterMessage(CPartnerApps_GetDepotBuildResult_Request)

CPartnerApps_GetDepotBuildResult_Response = _reflection.GeneratedProtocolMessageType('CPartnerApps_GetDepotBuildResult_Response', (_message.Message,), {
  'DESCRIPTOR' : _CPARTNERAPPS_GETDEPOTBUILDRESULT_RESPONSE,
  '__module__' : 'steammessages_partnerapps_pb2'
  # @@protoc_insertion_point(class_scope:CPartnerApps_GetDepotBuildResult_Response)
  })
_sym_db.RegisterMessage(CPartnerApps_GetDepotBuildResult_Response)

CPartnerApps_FindDRMUploads_Request = _reflection.GeneratedProtocolMessageType('CPartnerApps_FindDRMUploads_Request', (_message.Message,), {
  'DESCRIPTOR' : _CPARTNERAPPS_FINDDRMUPLOADS_REQUEST,
  '__module__' : 'steammessages_partnerapps_pb2'
  # @@protoc_insertion_point(class_scope:CPartnerApps_FindDRMUploads_Request)
  })
_sym_db.RegisterMessage(CPartnerApps_FindDRMUploads_Request)

CPartnerApps_ExistingDRMUpload = _reflection.GeneratedProtocolMessageType('CPartnerApps_ExistingDRMUpload', (_message.Message,), {
  'DESCRIPTOR' : _CPARTNERAPPS_EXISTINGDRMUPLOAD,
  '__module__' : 'steammessages_partnerapps_pb2'
  # @@protoc_insertion_point(class_scope:CPartnerApps_ExistingDRMUpload)
  })
_sym_db.RegisterMessage(CPartnerApps_ExistingDRMUpload)

CPartnerApps_FindDRMUploads_Response = _reflection.GeneratedProtocolMessageType('CPartnerApps_FindDRMUploads_Response', (_message.Message,), {
  'DESCRIPTOR' : _CPARTNERAPPS_FINDDRMUPLOADS_RESPONSE,
  '__module__' : 'steammessages_partnerapps_pb2'
  # @@protoc_insertion_point(class_scope:CPartnerApps_FindDRMUploads_Response)
  })
_sym_db.RegisterMessage(CPartnerApps_FindDRMUploads_Response)

CPartnerApps_Download_Request = _reflection.GeneratedProtocolMessageType('CPartnerApps_Download_Request', (_message.Message,), {
  'DESCRIPTOR' : _CPARTNERAPPS_DOWNLOAD_REQUEST,
  '__module__' : 'steammessages_partnerapps_pb2'
  # @@protoc_insertion_point(class_scope:CPartnerApps_Download_Request)
  })
_sym_db.RegisterMessage(CPartnerApps_Download_Request)

CPartnerApps_Download_Response = _reflection.GeneratedProtocolMessageType('CPartnerApps_Download_Response', (_message.Message,), {
  'DESCRIPTOR' : _CPARTNERAPPS_DOWNLOAD_RESPONSE,
  '__module__' : 'steammessages_partnerapps_pb2'
  # @@protoc_insertion_point(class_scope:CPartnerApps_Download_Response)
  })
_sym_db.RegisterMessage(CPartnerApps_Download_Response)


DESCRIPTOR._options = None

_PARTNERAPPS = _descriptor.ServiceDescriptor(
  name='PartnerApps',
  full_name='PartnerApps',
  file=DESCRIPTOR,
  index=0,
  serialized_options=b'\202\265\030.Service methods for app management by partners',
  create_key=_descriptor._internal_create_key,
  serialized_start=1506,
  serialized_end=3331,
  methods=[
  _descriptor.MethodDescriptor(
    name='RequestKVSignUploadToken',
    full_name='PartnerApps.RequestKVSignUploadToken',
    index=0,
    containing_service=None,
    input_type=_CPARTNERAPPS_REQUESTUPLOADTOKEN_REQUEST,
    output_type=_CPARTNERAPPS_REQUESTUPLOADTOKEN_RESPONSE,
    serialized_options=b'\202\265\030<Request upload token for installscript file upload / signing',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='RequestDRMUploadToken',
    full_name='PartnerApps.RequestDRMUploadToken',
    index=1,
    containing_service=None,
    input_type=_CPARTNERAPPS_REQUESTUPLOADTOKEN_REQUEST,
    output_type=_CPARTNERAPPS_REQUESTUPLOADTOKEN_RESPONSE,
    serialized_options=b'\202\265\030<Request upload token for executable file upload / processing',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='RequestCEGUploadToken',
    full_name='PartnerApps.RequestCEGUploadToken',
    index=2,
    containing_service=None,
    input_type=_CPARTNERAPPS_REQUESTUPLOADTOKEN_REQUEST,
    output_type=_CPARTNERAPPS_REQUESTUPLOADTOKEN_RESPONSE,
    serialized_options=b'\202\265\030CRequest upload token for custom executable file upload / processing',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='RequestDepotUploadToken',
    full_name='PartnerApps.RequestDepotUploadToken',
    index=3,
    containing_service=None,
    input_type=_CPARTNERAPPS_REQUESTUPLOADTOKEN_REQUEST,
    output_type=_CPARTNERAPPS_REQUESTUPLOADTOKEN_RESPONSE,
    serialized_options=b'\202\265\030/Request upload token for steampipe depot upload',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='FinishUploadKVSign',
    full_name='PartnerApps.FinishUploadKVSign',
    index=4,
    containing_service=None,
    input_type=_CPARTNERAPPS_FINISHUPLOAD_REQUEST,
    output_type=_CPARTNERAPPS_FINISHUPLOADKVSIGN_RESPONSE,
    serialized_options=b'\202\265\030BCommit method to sign an installscript after an upload is complete',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='FinishUploadDRMUpload',
    full_name='PartnerApps.FinishUploadDRMUpload',
    index=5,
    containing_service=None,
    input_type=_CPARTNERAPPS_FINISHUPLOADLEGACYDRM_REQUEST,
    output_type=_CPARTNERAPPS_FINISHUPLOADLEGACYDRM_RESPONSE,
    serialized_options=b'\202\265\030,Commit method for executable file processing',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='FinishUploadCEGUpload',
    full_name='PartnerApps.FinishUploadCEGUpload',
    index=6,
    containing_service=None,
    input_type=_CPARTNERAPPS_FINISHUPLOAD_REQUEST,
    output_type=_CPARTNERAPPS_FINISHUPLOAD_RESPONSE,
    serialized_options=b'\202\265\0303Commit method for custom executable file processing',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='FinishUploadDepotUpload',
    full_name='PartnerApps.FinishUploadDepotUpload',
    index=7,
    containing_service=None,
    input_type=_CPARTNERAPPS_FINISHUPLOADDEPOT_REQUEST,
    output_type=_CPARTNERAPPS_FINISHUPLOADDEPOT_RESPONSE,
    serialized_options=b'\202\265\0303Commit method for custom executable file processing',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetDepotBuildResult',
    full_name='PartnerApps.GetDepotBuildResult',
    index=8,
    containing_service=None,
    input_type=_CPARTNERAPPS_GETDEPOTBUILDRESULT_REQUEST,
    output_type=_CPARTNERAPPS_GETDEPOTBUILDRESULT_RESPONSE,
    serialized_options=b'\202\265\0302Get build status for previously uploaded depot ZIP',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='FindDRMUploads',
    full_name='PartnerApps.FindDRMUploads',
    index=9,
    containing_service=None,
    input_type=_CPARTNERAPPS_FINDDRMUPLOADS_REQUEST,
    output_type=_CPARTNERAPPS_FINDDRMUPLOADS_RESPONSE,
    serialized_options=b'\202\265\030*Finds N most recent prior uploads by appid',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Download',
    full_name='PartnerApps.Download',
    index=10,
    containing_service=None,
    input_type=_CPARTNERAPPS_DOWNLOAD_REQUEST,
    output_type=_CPARTNERAPPS_DOWNLOAD_RESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_PARTNERAPPS)

DESCRIPTOR.services_by_name['PartnerApps'] = _PARTNERAPPS

PartnerApps = service_reflection.GeneratedServiceType('PartnerApps', (_service.Service,), dict(
  DESCRIPTOR = _PARTNERAPPS,
  __module__ = 'steammessages_partnerapps_pb2'
  ))

PartnerApps_Stub = service_reflection.GeneratedServiceStubType('PartnerApps_Stub', (PartnerApps,), dict(
  DESCRIPTOR = _PARTNERAPPS,
  __module__ = 'steammessages_partnerapps_pb2'
  ))


# @@protoc_insertion_point(module_scope)



from datetime import datetime
from binascii import hexlify
from gevent.event import Event
from steam.steamid import SteamID
from steam.enums import EFriendRelationship, EPersonaState, EChatEntryType
from steam.enums.emsg import EMsg
from steam.core.msg import MsgProto

class SteamUser(object):
    """
    A data model for a Steam user. Holds user persona state, and related actions

    .. note::
        This is an internal object that can be obtained by :meth:`SteamClient.get_user`
    """
    _pstate = None
    _pstate_requested = False
    steam_id = SteamID()  #: steam id
    relationship = EFriendRelationship.NONE   #: friendship status

    def __init__(self, steam_id, steam):
        self._pstate_ready = Event()
        self._steam = steam
        self.steam_id = SteamID(steam_id)

    def __repr__(self):
        return "<%s(%s, %s, %s)>" % (
            self.__class__.__name__,
            str(self.steam_id),
            self.relationship,
            self.state,
            )

    def refresh(self, wait=True):
        if self._pstate_requested and self._pstate_ready.is_set():
            self._pstate_requested = False

        if not self._pstate_requested:
            self._steam.request_persona_state([self.steam_id])
            self._pstate_ready.clear()
            self._pstate_requested = True

        if wait:
            self._pstate_ready.wait(timeout=5)
            self._pstate_requested = False

    def get_ps(self, field_name, wait_pstate=True):
        """Get property from PersonaState

        `See full list of available fields_names <https://github.com/ValvePython/steam/blob/fa8a5127e9bb23185483930da0b6ae85e93055a7/protobufs/steammessages_clientserver_friends.proto#L125-L153>`_
        """
        if not self._pstate_ready.is_set() and wait_pstate:
            self.refresh()

        if self._pstate is not None:
            return getattr(self._pstate, field_name)
        else:
            return None

    @property
    def last_logon(self):
        """:rtype: :class:`datetime`, :class:`None`"""
        ts = self.get_ps('last_logon')
        return datetime.utcfromtimestamp(ts) if ts else None

    @property
    def last_logoff(self):
        """:rtype: :class:`datetime`, :class:`None`"""
        ts = self.get_ps('last_logoff')
        return datetime.utcfromtimestamp(ts) if ts else None

    @property
    def name(self):
        """Name of the steam user, or ``None`` if it's not available

        :rtype: :class:`str`, :class:`None`
        """
        return self.get_ps('player_name')

    @property
    def state(self):
        """Personsa state (e.g. Online, Offline, Away, Busy, etc)

        :rtype: :class:`.EPersonaState`
        """
        state = self.get_ps('persona_state', False)
        return EPersonaState(state) if state else EPersonaState.Offline

    @property
    def rich_presence(self):
        """Contains Rich Presence key-values

        :rtype: dict
        """
        kvs = self.get_ps('rich_presence')
        data = {}

        if kvs:
            for kv in kvs:
                data[kv.key] = kv.value

        return data

    def get_avatar_url(self, size=2):
        """Get URL to avatar picture

        :param size: possible values are ``0``, ``1``, or ``2`` corresponding to small, medium, large
        :type size: :class:`int`
        :return: url to avatar
        :rtype: :class:`str`
        """
        hashbytes = self.get_ps('avatar_hash')

        if hashbytes != "\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000":
            ahash = hexlify(hashbytes).decode('ascii')
        else:
            ahash = 'fef49e7fa7e1997310d705b2a6158ff8dc1cdfeb'

        sizes = {
            0: '',
            1: '_medium',
            2: '_full',
        }
        url = "http://cdn.akamai.steamstatic.com/steamcommunity/public/images/avatars/%s/%s%s.jpg"

        return url % (ahash[:2], ahash, sizes[size])

    def send_message(self, message):
        """Send chat message to this steam user

        :param message: message to send
        :type message: str
        """
        # new chat
        if self._steam.chat_mode == 2:
            self._steam.send_um("FriendMessages.SendMessage#1", {
                'steamid': self.steam_id,
                'message': message,
                'chat_entry_type': EChatEntryType.ChatMsg,
                })
        # old chat
        else:
            self._steam.send(MsgProto(EMsg.ClientFriendMsg), {
                'steamid': self.steam_id,
                'chat_entry_type': EChatEntryType.ChatMsg,
                'message': message.encode('utf8'),
                })

    def block(self):
        """Block user"""
        self._steam.friends.block(self)

    def unblock(self):
        """Unblock user"""
        self._steam.friends.unblock(self)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: offline_ticket.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='offline_ticket.proto',
  package='',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x14offline_ticket.proto\"w\n\x0eOffline_Ticket\x12\x18\n\x10\x65ncrypted_ticket\x18\x01 \x01(\x0c\x12\x11\n\tsignature\x18\x02 \x01(\x0c\x12\x0c\n\x04kdf1\x18\x03 \x01(\x05\x12\r\n\x05salt1\x18\x04 \x01(\x0c\x12\x0c\n\x04kdf2\x18\x05 \x01(\x05\x12\r\n\x05salt2\x18\x06 \x01(\x0c'
)




_OFFLINE_TICKET = _descriptor.Descriptor(
  name='Offline_Ticket',
  full_name='Offline_Ticket',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='encrypted_ticket', full_name='Offline_Ticket.encrypted_ticket', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='signature', full_name='Offline_Ticket.signature', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='kdf1', full_name='Offline_Ticket.kdf1', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='salt1', full_name='Offline_Ticket.salt1', index=3,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='kdf2', full_name='Offline_Ticket.kdf2', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='salt2', full_name='Offline_Ticket.salt2', index=5,
      number=6, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=24,
  serialized_end=143,
)

DESCRIPTOR.message_types_by_name['Offline_Ticket'] = _OFFLINE_TICKET
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Offline_Ticket = _reflection.GeneratedProtocolMessageType('Offline_Ticket', (_message.Message,), {
  'DESCRIPTOR' : _OFFLINE_TICKET,
  '__module__' : 'offline_ticket_pb2'
  # @@protoc_insertion_point(class_scope:Offline_Ticket)
  })
_sym_db.RegisterMessage(Offline_Ticket)


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: steammessages_video.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import service as _service
from google.protobuf import service_reflection
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import steam.protobufs.steammessages_base_pb2 as steammessages__base__pb2
import steam.protobufs.steammessages_unified_base_pb2 as steammessages__unified__base__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='steammessages_video.proto',
  package='',
  syntax='proto2',
  serialized_options=b'\220\001\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x19steammessages_video.proto\x1a\x18steammessages_base.proto\x1a steammessages_unified_base.proto\"\x81\x01\n CVideo_ClientGetVideoURL_Request\x12\x1e\n\x08video_id\x18\x01 \x01(\x04\x42\x0c\x82\xb5\x18\x08Video ID\x12=\n\rclient_cellid\x18\x02 \x01(\rB&\x82\xb5\x18\"Cell ID of client, zero if unknown\"r\n!CVideo_ClientGetVideoURL_Response\x12\x1e\n\x08video_id\x18\x01 \x01(\x04\x42\x0c\x82\xb5\x18\x08Video ID\x12-\n\tvideo_url\x18\x02 \x01(\tB\x1a\x82\xb5\x18\x16URL for video manifest\"\xaa\x04\n\rVideoBookmark\x12\x1a\n\x06\x61pp_id\x18\x01 \x01(\rB\n\x82\xb5\x18\x06\x41pp ID\x12]\n\x1cplayback_position_in_seconds\x18\x02 \x01(\rB7\x82\xb5\x18\x33How many seconds into the video the bookmark is for\x12/\n\x0evideo_track_id\x18\x03 \x01(\x04\x42\x17\x82\xb5\x18\x13video track choice.\x12/\n\x0e\x61udio_track_id\x18\x04 \x01(\x04\x42\x17\x82\xb5\x18\x13\x61udio track choice.\x12\x43\n\x12timedtext_track_id\x18\x05 \x01(\x04\x42\'\x82\xb5\x18#timedtimed or subtitle track choice\x12O\n\rlast_modified\x18\x06 \x01(\rB8\x82\xb5\x18\x34when we recorded it was last modified. Not settable.\x12U\n\x17hide_from_watch_history\x18\x07 \x01(\x08:\x05\x66\x61lseB-\x82\xb5\x18)Whether I want to show this in my history\x12O\n\x11hide_from_library\x18\x08 \x01(\x08:\x05\x66\x61lseB-\x82\xb5\x18)Whether I want to show this in my library\"r\n$CVideo_SetVideoBookmark_Notification\x12J\n\tbookmarks\x18\x01 \x03(\x0b\x32\x0e.VideoBookmarkB\'\x82\xb5\x18#list of bookmarks we want to store.\"\x81\x02\n CVideo_GetVideoBookmarks_Request\x12_\n\x06\x61ppids\x18\x01 \x03(\rBO\x82\xb5\x18KList of App IDs to grab bookmarks for. Can be empty if using updated_since.\x12|\n\rupdated_since\x18\x02 \x01(\rBe\x82\xb5\x18\x61Only return results after time. Min value is 1. (seconds since epoch January 1st, 1970 Unix Time)\"u\n!CVideo_GetVideoBookmarks_Response\x12P\n\tbookmarks\x18\x01 \x03(\x0b\x32\x0e.VideoBookmarkB-\x82\xb5\x18)List of bookmarks we found. Can be empty.\":\n CVideo_UnlockedH264_Notification\x12\x16\n\x0e\x65ncryption_key\x18\x01 \x01(\x0c\"\x85\x01\n(CFovasVideo_ClientGetOPFSettings_Request\x12\x1a\n\x06\x61pp_id\x18\x01 \x01(\rB\n\x82\xb5\x18\x06\x41pp ID\x12=\n\rclient_cellid\x18\x02 \x01(\rB&\x82\xb5\x18\"Cell ID of client, zero if unknown\"|\n)CFovasVideo_ClientGetOPFSettings_Response\x12\x1a\n\x06\x61pp_id\x18\x01 \x01(\rB\n\x82\xb5\x18\x06\x41pp ID\x12\x33\n\x0copf_settings\x18\x02 \x01(\tB\x1d\x82\xb5\x18\x19JSON blob of OPF Settings2\xb5\x04\n\x05Video\x12\x8e\x01\n\x11\x43lientGetVideoURL\x12!.CVideo_ClientGetVideoURL_Request\x1a\".CVideo_ClientGetVideoURL_Response\"2\x82\xb5\x18.Get the initial URL to begin streaming a video\x12\xc1\x01\n\x10SetVideoBookmark\x12%.CVideo_SetVideoBookmark_Notification\x1a\x0b.NoResponse\"y\x82\xb5\x18uBookmarks the locations in the video the user has reached. As as record playback settings per video. Fire and forget.\x12\xc3\x01\n\x11GetVideoBookmarks\x12!.CVideo_GetVideoBookmarks_Request\x1a\".CVideo_GetVideoBookmarks_Response\"g\x82\xb5\x18\x63Returns the video bookmarks locations for the specific videos. Includes playback settings per video\x1a\x11\x82\xb5\x18\rVideo methods2\x9e\x01\n\x0bVideoClient\x12\x88\x01\n\x12NotifyUnlockedH264\x12!.CVideo_UnlockedH264_Notification\x1a\x0b.NoResponse\"B\x82\xb5\x18>Notification from server to client that h264 has been unlocked\x1a\x04\xc0\xb5\x18\x02\x32\xf3\x01\n\nFovasVideo\x12\xc3\x01\n\x14\x43lientGetOPFSettings\x12).CFovasVideo_ClientGetOPFSettings_Request\x1a*.CFovasVideo_ClientGetOPFSettings_Response\"T\x82\xb5\x18PRetrieve the OPF settings JSON blob. Available via the Client for 360 Player App\x1a\x1f\x82\xb5\x18\x1b\x46ovas Video Service MethodsB\x03\x90\x01\x01'
  ,
  dependencies=[steammessages__base__pb2.DESCRIPTOR,steammessages__unified__base__pb2.DESCRIPTOR,])




_CVIDEO_CLIENTGETVIDEOURL_REQUEST = _descriptor.Descriptor(
  name='CVideo_ClientGetVideoURL_Request',
  full_name='CVideo_ClientGetVideoURL_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='video_id', full_name='CVideo_ClientGetVideoURL_Request.video_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\010Video ID', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='client_cellid', full_name='CVideo_ClientGetVideoURL_Request.client_cellid', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\"Cell ID of client, zero if unknown', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=90,
  serialized_end=219,
)


_CVIDEO_CLIENTGETVIDEOURL_RESPONSE = _descriptor.Descriptor(
  name='CVideo_ClientGetVideoURL_Response',
  full_name='CVideo_ClientGetVideoURL_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='video_id', full_name='CVideo_ClientGetVideoURL_Response.video_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\010Video ID', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='video_url', full_name='CVideo_ClientGetVideoURL_Response.video_url', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\026URL for video manifest', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=221,
  serialized_end=335,
)


_VIDEOBOOKMARK = _descriptor.Descriptor(
  name='VideoBookmark',
  full_name='VideoBookmark',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='app_id', full_name='VideoBookmark.app_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\006App ID', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='playback_position_in_seconds', full_name='VideoBookmark.playback_position_in_seconds', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\0303How many seconds into the video the bookmark is for', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='video_track_id', full_name='VideoBookmark.video_track_id', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\023video track choice.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='audio_track_id', full_name='VideoBookmark.audio_track_id', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\023audio track choice.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timedtext_track_id', full_name='VideoBookmark.timedtext_track_id', index=4,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030#timedtimed or subtitle track choice', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='last_modified', full_name='VideoBookmark.last_modified', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\0304when we recorded it was last modified. Not settable.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hide_from_watch_history', full_name='VideoBookmark.hide_from_watch_history', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030)Whether I want to show this in my history', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hide_from_library', full_name='VideoBookmark.hide_from_library', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030)Whether I want to show this in my library', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=338,
  serialized_end=892,
)


_CVIDEO_SETVIDEOBOOKMARK_NOTIFICATION = _descriptor.Descriptor(
  name='CVideo_SetVideoBookmark_Notification',
  full_name='CVideo_SetVideoBookmark_Notification',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='bookmarks', full_name='CVideo_SetVideoBookmark_Notification.bookmarks', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030#list of bookmarks we want to store.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=894,
  serialized_end=1008,
)


_CVIDEO_GETVIDEOBOOKMARKS_REQUEST = _descriptor.Descriptor(
  name='CVideo_GetVideoBookmarks_Request',
  full_name='CVideo_GetVideoBookmarks_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='appids', full_name='CVideo_GetVideoBookmarks_Request.appids', index=0,
      number=1, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030KList of App IDs to grab bookmarks for. Can be empty if using updated_since.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='updated_since', full_name='CVideo_GetVideoBookmarks_Request.updated_since', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030aOnly return results after time. Min value is 1. (seconds since epoch January 1st, 1970 Unix Time)', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1011,
  serialized_end=1268,
)


_CVIDEO_GETVIDEOBOOKMARKS_RESPONSE = _descriptor.Descriptor(
  name='CVideo_GetVideoBookmarks_Response',
  full_name='CVideo_GetVideoBookmarks_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='bookmarks', full_name='CVideo_GetVideoBookmarks_Response.bookmarks', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030)List of bookmarks we found. Can be empty.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1270,
  serialized_end=1387,
)


_CVIDEO_UNLOCKEDH264_NOTIFICATION = _descriptor.Descriptor(
  name='CVideo_UnlockedH264_Notification',
  full_name='CVideo_UnlockedH264_Notification',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='encryption_key', full_name='CVideo_UnlockedH264_Notification.encryption_key', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1389,
  serialized_end=1447,
)


_CFOVASVIDEO_CLIENTGETOPFSETTINGS_REQUEST = _descriptor.Descriptor(
  name='CFovasVideo_ClientGetOPFSettings_Request',
  full_name='CFovasVideo_ClientGetOPFSettings_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='app_id', full_name='CFovasVideo_ClientGetOPFSettings_Request.app_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\006App ID', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='client_cellid', full_name='CFovasVideo_ClientGetOPFSettings_Request.client_cellid', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\"Cell ID of client, zero if unknown', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1450,
  serialized_end=1583,
)


_CFOVASVIDEO_CLIENTGETOPFSETTINGS_RESPONSE = _descriptor.Descriptor(
  name='CFovasVideo_ClientGetOPFSettings_Response',
  full_name='CFovasVideo_ClientGetOPFSettings_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='app_id', full_name='CFovasVideo_ClientGetOPFSettings_Response.app_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\006App ID', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='opf_settings', full_name='CFovasVideo_ClientGetOPFSettings_Response.opf_settings', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\031JSON blob of OPF Settings', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1585,
  serialized_end=1709,
)

_CVIDEO_SETVIDEOBOOKMARK_NOTIFICATION.fields_by_name['bookmarks'].message_type = _VIDEOBOOKMARK
_CVIDEO_GETVIDEOBOOKMARKS_RESPONSE.fields_by_name['bookmarks'].message_type = _VIDEOBOOKMARK
DESCRIPTOR.message_types_by_name['CVideo_ClientGetVideoURL_Request'] = _CVIDEO_CLIENTGETVIDEOURL_REQUEST
DESCRIPTOR.message_types_by_name['CVideo_ClientGetVideoURL_Response'] = _CVIDEO_CLIENTGETVIDEOURL_RESPONSE
DESCRIPTOR.message_types_by_name['VideoBookmark'] = _VIDEOBOOKMARK
DESCRIPTOR.message_types_by_name['CVideo_SetVideoBookmark_Notification'] = _CVIDEO_SETVIDEOBOOKMARK_NOTIFICATION
DESCRIPTOR.message_types_by_name['CVideo_GetVideoBookmarks_Request'] = _CVIDEO_GETVIDEOBOOKMARKS_REQUEST
DESCRIPTOR.message_types_by_name['CVideo_GetVideoBookmarks_Response'] = _CVIDEO_GETVIDEOBOOKMARKS_RESPONSE
DESCRIPTOR.message_types_by_name['CVideo_UnlockedH264_Notification'] = _CVIDEO_UNLOCKEDH264_NOTIFICATION
DESCRIPTOR.message_types_by_name['CFovasVideo_ClientGetOPFSettings_Request'] = _CFOVASVIDEO_CLIENTGETOPFSETTINGS_REQUEST
DESCRIPTOR.message_types_by_name['CFovasVideo_ClientGetOPFSettings_Response'] = _CFOVASVIDEO_CLIENTGETOPFSETTINGS_RESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CVideo_ClientGetVideoURL_Request = _reflection.GeneratedProtocolMessageType('CVideo_ClientGetVideoURL_Request', (_message.Message,), {
  'DESCRIPTOR' : _CVIDEO_CLIENTGETVIDEOURL_REQUEST,
  '__module__' : 'steammessages_video_pb2'
  # @@protoc_insertion_point(class_scope:CVideo_ClientGetVideoURL_Request)
  })
_sym_db.RegisterMessage(CVideo_ClientGetVideoURL_Request)

CVideo_ClientGetVideoURL_Response = _reflection.GeneratedProtocolMessageType('CVideo_ClientGetVideoURL_Response', (_message.Message,), {
  'DESCRIPTOR' : _CVIDEO_CLIENTGETVIDEOURL_RESPONSE,
  '__module__' : 'steammessages_video_pb2'
  # @@protoc_insertion_point(class_scope:CVideo_ClientGetVideoURL_Response)
  })
_sym_db.RegisterMessage(CVideo_ClientGetVideoURL_Response)

VideoBookmark = _reflection.GeneratedProtocolMessageType('VideoBookmark', (_message.Message,), {
  'DESCRIPTOR' : _VIDEOBOOKMARK,
  '__module__' : 'steammessages_video_pb2'
  # @@protoc_insertion_point(class_scope:VideoBookmark)
  })
_sym_db.RegisterMessage(VideoBookmark)

CVideo_SetVideoBookmark_Notification = _reflection.GeneratedProtocolMessageType('CVideo_SetVideoBookmark_Notification', (_message.Message,), {
  'DESCRIPTOR' : _CVIDEO_SETVIDEOBOOKMARK_NOTIFICATION,
  '__module__' : 'steammessages_video_pb2'
  # @@protoc_insertion_point(class_scope:CVideo_SetVideoBookmark_Notification)
  })
_sym_db.RegisterMessage(CVideo_SetVideoBookmark_Notification)

CVideo_GetVideoBookmarks_Request = _reflection.GeneratedProtocolMessageType('CVideo_GetVideoBookmarks_Request', (_message.Message,), {
  'DESCRIPTOR' : _CVIDEO_GETVIDEOBOOKMARKS_REQUEST,
  '__module__' : 'steammessages_video_pb2'
  # @@protoc_insertion_point(class_scope:CVideo_GetVideoBookmarks_Request)
  })
_sym_db.RegisterMessage(CVideo_GetVideoBookmarks_Request)

CVideo_GetVideoBookmarks_Response = _reflection.GeneratedProtocolMessageType('CVideo_GetVideoBookmarks_Response', (_message.Message,), {
  'DESCRIPTOR' : _CVIDEO_GETVIDEOBOOKMARKS_RESPONSE,
  '__module__' : 'steammessages_video_pb2'
  # @@protoc_insertion_point(class_scope:CVideo_GetVideoBookmarks_Response)
  })
_sym_db.RegisterMessage(CVideo_GetVideoBookmarks_Response)

CVideo_UnlockedH264_Notification = _reflection.GeneratedProtocolMessageType('CVideo_UnlockedH264_Notification', (_message.Message,), {
  'DESCRIPTOR' : _CVIDEO_UNLOCKEDH264_NOTIFICATION,
  '__module__' : 'steammessages_video_pb2'
  # @@protoc_insertion_point(class_scope:CVideo_UnlockedH264_Notification)
  })
_sym_db.RegisterMessage(CVideo_UnlockedH264_Notification)

CFovasVideo_ClientGetOPFSettings_Request = _reflection.GeneratedProtocolMessageType('CFovasVideo_ClientGetOPFSettings_Request', (_message.Message,), {
  'DESCRIPTOR' : _CFOVASVIDEO_CLIENTGETOPFSETTINGS_REQUEST,
  '__module__' : 'steammessages_video_pb2'
  # @@protoc_insertion_point(class_scope:CFovasVideo_ClientGetOPFSettings_Request)
  })
_sym_db.RegisterMessage(CFovasVideo_ClientGetOPFSettings_Request)

CFovasVideo_ClientGetOPFSettings_Response = _reflection.GeneratedProtocolMessageType('CFovasVideo_ClientGetOPFSettings_Response', (_message.Message,), {
  'DESCRIPTOR' : _CFOVASVIDEO_CLIENTGETOPFSETTINGS_RESPONSE,
  '__module__' : 'steammessages_video_pb2'
  # @@protoc_insertion_point(class_scope:CFovasVideo_ClientGetOPFSettings_Response)
  })
_sym_db.RegisterMessage(CFovasVideo_ClientGetOPFSettings_Response)


DESCRIPTOR._options = None
_CVIDEO_CLIENTGETVIDEOURL_REQUEST.fields_by_name['video_id']._options = None
_CVIDEO_CLIENTGETVIDEOURL_REQUEST.fields_by_name['client_cellid']._options = None
_CVIDEO_CLIENTGETVIDEOURL_RESPONSE.fields_by_name['video_id']._options = None
_CVIDEO_CLIENTGETVIDEOURL_RESPONSE.fields_by_name['video_url']._options = None
_VIDEOBOOKMARK.fields_by_name['app_id']._options = None
_VIDEOBOOKMARK.fields_by_name['playback_position_in_seconds']._options = None
_VIDEOBOOKMARK.fields_by_name['video_track_id']._options = None
_VIDEOBOOKMARK.fields_by_name['audio_track_id']._options = None
_VIDEOBOOKMARK.fields_by_name['timedtext_track_id']._options = None
_VIDEOBOOKMARK.fields_by_name['last_modified']._options = None
_VIDEOBOOKMARK.fields_by_name['hide_from_watch_history']._options = None
_VIDEOBOOKMARK.fields_by_name['hide_from_library']._options = None
_CVIDEO_SETVIDEOBOOKMARK_NOTIFICATION.fields_by_name['bookmarks']._options = None
_CVIDEO_GETVIDEOBOOKMARKS_REQUEST.fields_by_name['appids']._options = None
_CVIDEO_GETVIDEOBOOKMARKS_REQUEST.fields_by_name['updated_since']._options = None
_CVIDEO_GETVIDEOBOOKMARKS_RESPONSE.fields_by_name['bookmarks']._options = None
_CFOVASVIDEO_CLIENTGETOPFSETTINGS_REQUEST.fields_by_name['app_id']._options = None
_CFOVASVIDEO_CLIENTGETOPFSETTINGS_REQUEST.fields_by_name['client_cellid']._options = None
_CFOVASVIDEO_CLIENTGETOPFSETTINGS_RESPONSE.fields_by_name['app_id']._options = None
_CFOVASVIDEO_CLIENTGETOPFSETTINGS_RESPONSE.fields_by_name['opf_settings']._options = None

_VIDEO = _descriptor.ServiceDescriptor(
  name='Video',
  full_name='Video',
  file=DESCRIPTOR,
  index=0,
  serialized_options=b'\202\265\030\rVideo methods',
  create_key=_descriptor._internal_create_key,
  serialized_start=1712,
  serialized_end=2277,
  methods=[
  _descriptor.MethodDescriptor(
    name='ClientGetVideoURL',
    full_name='Video.ClientGetVideoURL',
    index=0,
    containing_service=None,
    input_type=_CVIDEO_CLIENTGETVIDEOURL_REQUEST,
    output_type=_CVIDEO_CLIENTGETVIDEOURL_RESPONSE,
    serialized_options=b'\202\265\030.Get the initial URL to begin streaming a video',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetVideoBookmark',
    full_name='Video.SetVideoBookmark',
    index=1,
    containing_service=None,
    input_type=_CVIDEO_SETVIDEOBOOKMARK_NOTIFICATION,
    output_type=steammessages__unified__base__pb2._NORESPONSE,
    serialized_options=b'\202\265\030uBookmarks the locations in the video the user has reached. As as record playback settings per video. Fire and forget.',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetVideoBookmarks',
    full_name='Video.GetVideoBookmarks',
    index=2,
    containing_service=None,
    input_type=_CVIDEO_GETVIDEOBOOKMARKS_REQUEST,
    output_type=_CVIDEO_GETVIDEOBOOKMARKS_RESPONSE,
    serialized_options=b'\202\265\030cReturns the video bookmarks locations for the specific videos. Includes playback settings per video',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_VIDEO)

DESCRIPTOR.services_by_name['Video'] = _VIDEO


_VIDEOCLIENT = _descriptor.ServiceDescriptor(
  name='VideoClient',
  full_name='VideoClient',
  file=DESCRIPTOR,
  index=1,
  serialized_options=b'\300\265\030\002',
  create_key=_descriptor._internal_create_key,
  serialized_start=2280,
  serialized_end=2438,
  methods=[
  _descriptor.MethodDescriptor(
    name='NotifyUnlockedH264',
    full_name='VideoClient.NotifyUnlockedH264',
    index=0,
    containing_service=None,
    input_type=_CVIDEO_UNLOCKEDH264_NOTIFICATION,
    output_type=steammessages__unified__base__pb2._NORESPONSE,
    serialized_options=b'\202\265\030>Notification from server to client that h264 has been unlocked',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_VIDEOCLIENT)

DESCRIPTOR.services_by_name['VideoClient'] = _VIDEOCLIENT


_FOVASVIDEO = _descriptor.ServiceDescriptor(
  name='FovasVideo',
  full_name='FovasVideo',
  file=DESCRIPTOR,
  index=2,
  serialized_options=b'\202\265\030\033Fovas Video Service Methods',
  create_key=_descriptor._internal_create_key,
  serialized_start=2441,
  serialized_end=2684,
  methods=[
  _descriptor.MethodDescriptor(
    name='ClientGetOPFSettings',
    full_name='FovasVideo.ClientGetOPFSettings',
    index=0,
    containing_service=None,
    input_type=_CFOVASVIDEO_CLIENTGETOPFSETTINGS_REQUEST,
    output_type=_CFOVASVIDEO_CLIENTGETOPFSETTINGS_RESPONSE,
    serialized_options=b'\202\265\030PRetrieve the OPF settings JSON blob. Available via the Client for 360 Player App',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_FOVASVIDEO)

DESCRIPTOR.services_by_name['FovasVideo'] = _FOVASVIDEO

Video = service_reflection.GeneratedServiceType('Video', (_service.Service,), dict(
  DESCRIPTOR = _VIDEO,
  __module__ = 'steammessages_video_pb2'
  ))

Video_Stub = service_reflection.GeneratedServiceStubType('Video_Stub', (Video,), dict(
  DESCRIPTOR = _VIDEO,
  __module__ = 'steammessages_video_pb2'
  ))


VideoClient = service_reflection.GeneratedServiceType('VideoClient', (_service.Service,), dict(
  DESCRIPTOR = _VIDEOCLIENT,
  __module__ = 'steammessages_video_pb2'
  ))

VideoClient_Stub = service_reflection.GeneratedServiceStubType('VideoClient_Stub', (VideoClient,), dict(
  DESCRIPTOR = _VIDEOCLIENT,
  __module__ = 'steammessages_video_pb2'
  ))


FovasVideo = service_reflection.GeneratedServiceType('FovasVideo', (_service.Service,), dict(
  DESCRIPTOR = _FOVASVIDEO,
  __module__ = 'steammessages_video_pb2'
  ))

FovasVideo_Stub = service_reflection.GeneratedServiceStubType('FovasVideo_Stub', (FovasVideo,), dict(
  DESCRIPTOR = _FOVASVIDEO,
  __module__ = 'steammessages_video_pb2'
  ))


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: steammessages_unified_test.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import service as _service
from google.protobuf import service_reflection
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import steam.protobufs.steammessages_base_pb2 as steammessages__base__pb2
import steam.protobufs.steammessages_unified_base_pb2 as steammessages__unified__base__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='steammessages_unified_test.proto',
  package='',
  syntax='proto2',
  serialized_options=b'\220\001\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n steammessages_unified_test.proto\x1a\x18steammessages_base.proto\x1a steammessages_unified_base.proto\"G\n CMsgTest_MessageToClient_Request\x12#\n\tsome_text\x18\x01 \x01(\tB\x10\x82\xb5\x18\x0cSome string.\"H\n!CMsgTest_MessageToClient_Response\x12#\n\tsome_text\x18\x01 \x01(\tB\x10\x82\xb5\x18\x0cSome string.\"I\n\"CMsgTest_NotifyClient_Notification\x12#\n\tsome_text\x18\x01 \x01(\tB\x10\x82\xb5\x18\x0cSome string.\"G\n CMsgTest_MessageToServer_Request\x12#\n\tsome_text\x18\x01 \x01(\tB\x10\x82\xb5\x18\x0cSome string.\"H\n!CMsgTest_MessageToServer_Response\x12#\n\tsome_text\x18\x01 \x01(\tB\x10\x82\xb5\x18\x0cSome string.\"I\n\"CMsgTest_NotifyServer_Notification\x12#\n\tsome_text\x18\x01 \x01(\tB\x10\x82\xb5\x18\x0cSome string.2\x83\x02\n\x0fTestSteamClient\x12\x81\x01\n\x0fMessageToClient\x12!.CMsgTest_MessageToClient_Request\x1a\".CMsgTest_MessageToClient_Response\"\'\x82\xb5\x18#Some description - MessageToClient.\x12\x66\n\x0cNotifyClient\x12#.CMsgTest_NotifyClient_Notification\x1a\x0b.NoResponse\"$\x82\xb5\x18 Some description - NotifyClient.\x1a\x04\xc0\xb5\x18\x02\x32\x82\x02\n\x14TestServerFromClient\x12\x81\x01\n\x0fMessageToServer\x12!.CMsgTest_MessageToServer_Request\x1a\".CMsgTest_MessageToServer_Response\"\'\x82\xb5\x18#Some description - MessageToServer.\x12\x66\n\x0cNotifyServer\x12#.CMsgTest_NotifyServer_Notification\x1a\x0b.NoResponse\"$\x82\xb5\x18 Some description - NotifyServer.B\x03\x90\x01\x01'
  ,
  dependencies=[steammessages__base__pb2.DESCRIPTOR,steammessages__unified__base__pb2.DESCRIPTOR,])




_CMSGTEST_MESSAGETOCLIENT_REQUEST = _descriptor.Descriptor(
  name='CMsgTest_MessageToClient_Request',
  full_name='CMsgTest_MessageToClient_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='some_text', full_name='CMsgTest_MessageToClient_Request.some_text', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\014Some string.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=96,
  serialized_end=167,
)


_CMSGTEST_MESSAGETOCLIENT_RESPONSE = _descriptor.Descriptor(
  name='CMsgTest_MessageToClient_Response',
  full_name='CMsgTest_MessageToClient_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='some_text', full_name='CMsgTest_MessageToClient_Response.some_text', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\014Some string.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=169,
  serialized_end=241,
)


_CMSGTEST_NOTIFYCLIENT_NOTIFICATION = _descriptor.Descriptor(
  name='CMsgTest_NotifyClient_Notification',
  full_name='CMsgTest_NotifyClient_Notification',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='some_text', full_name='CMsgTest_NotifyClient_Notification.some_text', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\014Some string.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=243,
  serialized_end=316,
)


_CMSGTEST_MESSAGETOSERVER_REQUEST = _descriptor.Descriptor(
  name='CMsgTest_MessageToServer_Request',
  full_name='CMsgTest_MessageToServer_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='some_text', full_name='CMsgTest_MessageToServer_Request.some_text', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\014Some string.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=318,
  serialized_end=389,
)


_CMSGTEST_MESSAGETOSERVER_RESPONSE = _descriptor.Descriptor(
  name='CMsgTest_MessageToServer_Response',
  full_name='CMsgTest_MessageToServer_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='some_text', full_name='CMsgTest_MessageToServer_Response.some_text', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\014Some string.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=391,
  serialized_end=463,
)


_CMSGTEST_NOTIFYSERVER_NOTIFICATION = _descriptor.Descriptor(
  name='CMsgTest_NotifyServer_Notification',
  full_name='CMsgTest_NotifyServer_Notification',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='some_text', full_name='CMsgTest_NotifyServer_Notification.some_text', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\014Some string.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=465,
  serialized_end=538,
)

DESCRIPTOR.message_types_by_name['CMsgTest_MessageToClient_Request'] = _CMSGTEST_MESSAGETOCLIENT_REQUEST
DESCRIPTOR.message_types_by_name['CMsgTest_MessageToClient_Response'] = _CMSGTEST_MESSAGETOCLIENT_RESPONSE
DESCRIPTOR.message_types_by_name['CMsgTest_NotifyClient_Notification'] = _CMSGTEST_NOTIFYCLIENT_NOTIFICATION
DESCRIPTOR.message_types_by_name['CMsgTest_MessageToServer_Request'] = _CMSGTEST_MESSAGETOSERVER_REQUEST
DESCRIPTOR.message_types_by_name['CMsgTest_MessageToServer_Response'] = _CMSGTEST_MESSAGETOSERVER_RESPONSE
DESCRIPTOR.message_types_by_name['CMsgTest_NotifyServer_Notification'] = _CMSGTEST_NOTIFYSERVER_NOTIFICATION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CMsgTest_MessageToClient_Request = _reflection.GeneratedProtocolMessageType('CMsgTest_MessageToClient_Request', (_message.Message,), {
  'DESCRIPTOR' : _CMSGTEST_MESSAGETOCLIENT_REQUEST,
  '__module__' : 'steammessages_unified_test_pb2'
  # @@protoc_insertion_point(class_scope:CMsgTest_MessageToClient_Request)
  })
_sym_db.RegisterMessage(CMsgTest_MessageToClient_Request)

CMsgTest_MessageToClient_Response = _reflection.GeneratedProtocolMessageType('CMsgTest_MessageToClient_Response', (_message.Message,), {
  'DESCRIPTOR' : _CMSGTEST_MESSAGETOCLIENT_RESPONSE,
  '__module__' : 'steammessages_unified_test_pb2'
  # @@protoc_insertion_point(class_scope:CMsgTest_MessageToClient_Response)
  })
_sym_db.RegisterMessage(CMsgTest_MessageToClient_Response)

CMsgTest_NotifyClient_Notification = _reflection.GeneratedProtocolMessageType('CMsgTest_NotifyClient_Notification', (_message.Message,), {
  'DESCRIPTOR' : _CMSGTEST_NOTIFYCLIENT_NOTIFICATION,
  '__module__' : 'steammessages_unified_test_pb2'
  # @@protoc_insertion_point(class_scope:CMsgTest_NotifyClient_Notification)
  })
_sym_db.RegisterMessage(CMsgTest_NotifyClient_Notification)

CMsgTest_MessageToServer_Request = _reflection.GeneratedProtocolMessageType('CMsgTest_MessageToServer_Request', (_message.Message,), {
  'DESCRIPTOR' : _CMSGTEST_MESSAGETOSERVER_REQUEST,
  '__module__' : 'steammessages_unified_test_pb2'
  # @@protoc_insertion_point(class_scope:CMsgTest_MessageToServer_Request)
  })
_sym_db.RegisterMessage(CMsgTest_MessageToServer_Request)

CMsgTest_MessageToServer_Response = _reflection.GeneratedProtocolMessageType('CMsgTest_MessageToServer_Response', (_message.Message,), {
  'DESCRIPTOR' : _CMSGTEST_MESSAGETOSERVER_RESPONSE,
  '__module__' : 'steammessages_unified_test_pb2'
  # @@protoc_insertion_point(class_scope:CMsgTest_MessageToServer_Response)
  })
_sym_db.RegisterMessage(CMsgTest_MessageToServer_Response)

CMsgTest_NotifyServer_Notification = _reflection.GeneratedProtocolMessageType('CMsgTest_NotifyServer_Notification', (_message.Message,), {
  'DESCRIPTOR' : _CMSGTEST_NOTIFYSERVER_NOTIFICATION,
  '__module__' : 'steammessages_unified_test_pb2'
  # @@protoc_insertion_point(class_scope:CMsgTest_NotifyServer_Notification)
  })
_sym_db.RegisterMessage(CMsgTest_NotifyServer_Notification)


DESCRIPTOR._options = None
_CMSGTEST_MESSAGETOCLIENT_REQUEST.fields_by_name['some_text']._options = None
_CMSGTEST_MESSAGETOCLIENT_RESPONSE.fields_by_name['some_text']._options = None
_CMSGTEST_NOTIFYCLIENT_NOTIFICATION.fields_by_name['some_text']._options = None
_CMSGTEST_MESSAGETOSERVER_REQUEST.fields_by_name['some_text']._options = None
_CMSGTEST_MESSAGETOSERVER_RESPONSE.fields_by_name['some_text']._options = None
_CMSGTEST_NOTIFYSERVER_NOTIFICATION.fields_by_name['some_text']._options = None

_TESTSTEAMCLIENT = _descriptor.ServiceDescriptor(
  name='TestSteamClient',
  full_name='TestSteamClient',
  file=DESCRIPTOR,
  index=0,
  serialized_options=b'\300\265\030\002',
  create_key=_descriptor._internal_create_key,
  serialized_start=541,
  serialized_end=800,
  methods=[
  _descriptor.MethodDescriptor(
    name='MessageToClient',
    full_name='TestSteamClient.MessageToClient',
    index=0,
    containing_service=None,
    input_type=_CMSGTEST_MESSAGETOCLIENT_REQUEST,
    output_type=_CMSGTEST_MESSAGETOCLIENT_RESPONSE,
    serialized_options=b'\202\265\030#Some description - MessageToClient.',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='NotifyClient',
    full_name='TestSteamClient.NotifyClient',
    index=1,
    containing_service=None,
    input_type=_CMSGTEST_NOTIFYCLIENT_NOTIFICATION,
    output_type=steammessages__unified__base__pb2._NORESPONSE,
    serialized_options=b'\202\265\030 Some description - NotifyClient.',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_TESTSTEAMCLIENT)

DESCRIPTOR.services_by_name['TestSteamClient'] = _TESTSTEAMCLIENT


_TESTSERVERFROMCLIENT = _descriptor.ServiceDescriptor(
  name='TestServerFromClient',
  full_name='TestServerFromClient',
  file=DESCRIPTOR,
  index=1,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=803,
  serialized_end=1061,
  methods=[
  _descriptor.MethodDescriptor(
    name='MessageToServer',
    full_name='TestServerFromClient.MessageToServer',
    index=0,
    containing_service=None,
    input_type=_CMSGTEST_MESSAGETOSERVER_REQUEST,
    output_type=_CMSGTEST_MESSAGETOSERVER_RESPONSE,
    serialized_options=b'\202\265\030#Some description - MessageToServer.',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='NotifyServer',
    full_name='TestServerFromClient.NotifyServer',
    index=1,
    containing_service=None,
    input_type=_CMSGTEST_NOTIFYSERVER_NOTIFICATION,
    output_type=steammessages__unified__base__pb2._NORESPONSE,
    serialized_options=b'\202\265\030 Some description - NotifyServer.',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_TESTSERVERFROMCLIENT)

DESCRIPTOR.services_by_name['TestServerFromClient'] = _TESTSERVERFROMCLIENT

TestSteamClient = service_reflection.GeneratedServiceType('TestSteamClient', (_service.Service,), dict(
  DESCRIPTOR = _TESTSTEAMCLIENT,
  __module__ = 'steammessages_unified_test_pb2'
  ))

TestSteamClient_Stub = service_reflection.GeneratedServiceStubType('TestSteamClient_Stub', (TestSteamClient,), dict(
  DESCRIPTOR = _TESTSTEAMCLIENT,
  __module__ = 'steammessages_unified_test_pb2'
  ))


TestServerFromClient = service_reflection.GeneratedServiceType('TestServerFromClient', (_service.Service,), dict(
  DESCRIPTOR = _TESTSERVERFROMCLIENT,
  __module__ = 'steammessages_unified_test_pb2'
  ))

TestServerFromClient_Stub = service_reflection.GeneratedServiceStubType('TestServerFromClient_Stub', (TestServerFromClient,), dict(
  DESCRIPTOR = _TESTSERVERFROMCLIENT,
  __module__ = 'steammessages_unified_test_pb2'
  ))


# @@protoc_insertion_point(module_scope)



from struct import unpack_from as _unpack_from, calcsize as _calcsize


class StructReader(object):
    def __init__(self, data):
        """Simplifies parsing of struct data from bytes

        :param data: data bytes
        :type  data: :class:`bytes`
        """
        if not isinstance(data, bytes):
            raise ValueError("Only works with bytes")
        self.data = data
        self.offset = 0

    def __len__(self):
        return len(self.data)

    def rlen(self):
        """Number of remaining bytes that can be read

        :return: number of remaining bytes
        :rtype: :class:`int`
        """
        return max(0, len(self) - self.offset)

    def read(self, n=1):
        """Return n bytes

        :param n: number of bytes to return
        :type  n: :class:`int`
        :return: bytes
        :rtype: :class:`bytes`
        """
        self.offset += n
        return self.data[self.offset - n:self.offset]

    def read_cstring(self, terminator=b'\x00'):
        """Reads a single null termianted string

        :return: string without bytes
        :rtype: :class:`bytes`
        """
        null_index = self.data.find(terminator, self.offset)
        if null_index == -1:
            raise RuntimeError("Reached end of buffer")
        result = self.data[self.offset:null_index]  # bytes without the terminator
        self.offset = null_index + len(terminator)  # advance offset past terminator
        return result

    def unpack(self, format_text):
        """Unpack bytes using struct modules format

        :param format_text: struct's module format
        :type  format_text: :class:`str`
        :return data: result from :func:`struct.unpack_from`
        :rtype: :class:`tuple`
        """
        data = _unpack_from(format_text, self.data, self.offset)
        self.offset += _calcsize(format_text)
        return data

    def skip(self, n):
        """Skips the next ``n`` bytes

        :param n: number of bytes to skip
        :type  n: :class:`int`
        """
        self.offset += n
